@@ -516,10 +516,19 @@ macro_rules! define_main_error {
             &self.0
         }
 
+
+        pub fn into_detail(self) -> [< $name Detail >] {
+            self.0
+        }
+
         pub fn trace(&self) -> &$tracer {
             &self.1
         }
 
+        pub fn into_trace(self) -> $tracer {
+            self.1
+        }
+
         pub fn add_trace<E: ::core::fmt::Display>(self, message: &E) -> Self
         where
             $tracer: $crate::ErrorMessageTracer,
@@ -562,13 +571,13 @@ macro_rules! define_std_err_impl {
     @name( $name:ident ) $(,)?
   ) => {
     $crate::macros::paste![
-      impl ::std::error::Error for $name
+      impl $crate::StdError for $name
       where
           [< $name Detail >]: ::core::fmt::Display,
           $tracer: ::core::fmt::Debug + ::core::fmt::Display,
           $tracer: $crate::ErrorMessageTracer,
       {
-          fn source(&self) -> ::core::option::Option<&(dyn ::std::error::Error + 'static)> {
+          fn source(&self) -> ::core::option::Option<&(dyn $crate::StdError + 'static)> {
               $crate::ErrorMessageTracer::as_error(self.trace())
           }
       }
